==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningRadialMarkerStyleEventArgs", function () { return new AssigningRadialMarkerStyleEventArgsDescription(); });
        a.z("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.ac("AssigningRadialMarkerStyleEventArgs", function () { return new AssigningRadialMarkerStyleEventArgsDescription(); });
        a.ab("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialMarkerStyleEventArgsDescriptionMetadata };
